function [samples_time] = decompress_to_time(compressed_real, ...
    compressed_imag, dict_real, dict_imag, window_size)

%Decompress the real component
uncompressed_real = huffmandeco(compressed_real, dict_real);

%Decompress the imaginary component
uncompressed_imag = huffmandeco(compressed_imag, dict_imag);

%Combine the real and imaginary components
windowed_freqs = uncompressed_real + sqrt(-1)*uncompressed_imag;

%Allocate an empty vector for vertcat
samples_time = zeros(0, 1);

%Frequency window size is half the window_size
freq_window_size = window_size/2;

%Calculate the number of windows based on the freq_window_size
windows = length(windowed_freqs)/freq_window_size;

%Iterate through all windows
for w = 1:windows
    %Extract one window of frequencies
    freq_extract = windowed_freqs(((w-1)*freq_window_size)+1: ... 
        w*freq_window_size, :);
    
    %Calculate complex conjugates
    ifft_data = calc_conjugate(freq_extract);
    
    %IFFT
    time_samples_window = ifft(ifft_data, 'symmetric');
    
    %Adds time_samples_window for this window to the running list of
    %time samples
    samples_time = vertcat(samples_time, time_samples_window);
end  
